"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const program = require("commander");
const inquirer = require("inquirer");
const birthday_1 = require("./birthday");
const config_1 = require("./utils/config");
const configBirthdayNames = [];
let config = {
    firstLogin: true,
    save: false,
    username: '',
    password: '',
    birthday: true,
    wish: '',
    day: 1,
    birthdayNames: configBirthdayNames,
};
const pkg = require('../package.json');
const loginText = '\nPlease wait! Logging & Fetching Birthdays!...\n';
program.version(pkg.version)
    .description('Facebook Birthday CLI')
    .command('*', '', { noHelp: true, isDefault: true })
    .action(() => {
    program.help();
});
program.command('wish')
    .alias('w')
    .description('Facebook wish command')
    .option('-a, --all', 'wish all friends')
    .option('-r, --reset', 'resets all config values to default')
    .action((options) => __awaiter(this, void 0, void 0, function* () {
    try {
        if (!(yield config_1.configFileExists())) {
            yield config_1.writeFile(config);
        }
        const savedConfig = require(yield config_1.getConfigPath());
        if (options.reset) {
            yield config_1.writeFile(config);
            console.log(chalk_1.default.green('\nSuccessfully reset to default values! Please run "facebook wish" to start over.\n'));
        }
        else {
            const today = new Date().getDay();
            const Wisher = new birthday_1.BirthdayWisher();
            let credentials;
            if (savedConfig.firstLogin === true) {
                console.log('\n');
                config.day = today;
                credentials = yield inquirer.prompt([
                    {
                        message: 'Please enter your facebook username:',
                        name: 'username',
                        type: 'input',
                    },
                    {
                        message: 'Please enter your facebook password:',
                        name: 'password',
                        mask: '*',
                        type: 'password',
                    },
                ]);
                console.log(chalk_1.default.yellowBright(loginText));
                config = yield Wisher.login(credentials, config, savedConfig);
            }
            else {
                if (savedConfig.birthday === false) {
                    console.error(chalk_1.default.red('\n' +
                        'Today none of your friends have birthdays, Please try tomorrow!' +
                        '\n'));
                    process.exit(0);
                }
                if (savedConfig.day === today && savedConfig.birthdayNames.length === 0) {
                    console.error(chalk_1.default.red('\n' +
                        'You have wished all your friends, Please try tomorrow!' +
                        '\n'));
                    process.exit(0);
                }
                const savedCredentials = {};
                config_1.decryptCredentials(savedConfig, savedCredentials);
                console.log(chalk_1.default.yellowBright(loginText));
                config = yield Wisher.login(savedCredentials, config, savedConfig);
            }
            if (!options.all) {
                config = yield Wisher.findAndWish(config, savedConfig);
            }
            else {
                if (!savedConfig.save) {
                    birthday_1.wishes.splice(birthday_1.wishes.indexOf('custom message'), 1);
                    const answer = yield inquirer.prompt([
                        {
                            choices: birthday_1.wishes,
                            message: 'Select your favourite birthday wish:',
                            name: 'wish',
                            type: 'list',
                        },
                        {
                            default: true,
                            message: 'Do you want to save this message?',
                            name: 'message',
                            type: 'confirm',
                        },
                    ]);
                    if (answer.message) {
                        config.save = true;
                        config.wish = answer.wish;
                    }
                    config = yield Wisher.findAndWishAll(answer.wish, config, savedConfig);
                }
                else {
                    config = yield Wisher.findAndWishAll(savedConfig.wish, config, savedConfig);
                }
            }
            yield config_1.writeFile(config);
            process.exit(0);
        }
    }
    catch (Exception) {
        console.error(chalk_1.default.red('\n' + Exception.toString() + '\n'));
        process.exit(0);
    }
}));
program.parse(process.argv);
if (!program.args.length) {
    program.help();
}
//# sourceMappingURL=cli.js.map